#[non_exhaustive]pub struct ValidatedPath {
pub anchor_index: usize,
pub depth: usize,
}Expand description
The result of a successful certificate path validation.
Fields are pub for direct read access. #[non_exhaustive] prevents external
code from constructing ValidatedPath directly and from pattern-matching
exhaustively, preserving the ability to add fields in future minor versions
without a breaking change.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.anchor_index: usizeIndex into the anchors slice of the trust anchor that terminated the path.
depth: usizeDepth of the validated chain (number of intermediates, excluding trust anchor).